@@ -3,7 +3,7 @@
 // Purpose:     Canvas items
 // Author:      Alex Thuering
 // Created:     2005/05/09
-// RCS-ID:      $Id: SVGCanvasItem.h,v 1.22 2012/01/06 03:12:45 ntalex Exp $
+// RCS-ID:      $Id: SVGCanvasItem.h,v 1.25 2013/08/25 12:53:34 ntalex Exp $
 // Copyright:   (c) 2005 Alex Thuering
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -14,18 +14,17 @@
 #include "svg.h"
 #include <wx/dynarray.h>
 
+enum wxSVGCanvasItemType {
+	wxSVG_CANVAS_ITEM_PATH,
+	wxSVG_CANVAS_ITEM_TEXT,
+	wxSVG_CANVAS_ITEM_IMAGE,
+	wxSVG_CANVAS_ITEM_VIDEO
+};
+
 /** Base class for canvas items */
 class wxSVGCanvasItem
 {
   public:
-	enum wxSVGCanvasItemType
-	{
-	  wxSVG_CANVAS_ITEM_PATH,
-	  wxSVG_CANVAS_ITEM_TEXT,
-	  wxSVG_CANVAS_ITEM_IMAGE,
-	  wxSVG_CANVAS_ITEM_VIDEO
-	};
-	
 	wxSVGCanvasItem(wxSVGCanvasItemType type) { m_type = type; }
 	virtual ~wxSVGCanvasItem() {}
 	wxSVGCanvasItemType GetType() { return m_type; }
@@ -110,7 +109,7 @@ class wxSVGCanvasText: public wxSVGCanvasItem
 	wxSVGCanvasText(wxSVGCanvas* canvas);
 	virtual ~wxSVGCanvasText();
 	
-	virtual void Init(wxSVGTextElement& element, const wxCSSStyleDeclaration& style);
+	virtual void Init(wxSVGTextElement& element, const wxCSSStyleDeclaration& style, wxSVGMatrix* matrix);
     virtual wxSVGRect GetBBox(const wxSVGMatrix& matrix = *(wxSVGMatrix*)NULL);
 	virtual long GetNumberOfChars();
     virtual double GetComputedTextLength();
@@ -133,24 +132,27 @@ class wxSVGCanvasText: public wxSVGCanvasItem
 	double m_textAnchorBeginPos; /** x-coordinate of text with current text anchor */
 	wxCSS_VALUE m_dominantBaseline; /** current dominant baseline */
     int m_dominantBaselineBeginIndex; /** index of first chunk with current baseline */
-	virtual void Init(wxSVGTSpanElement& element, const wxCSSStyleDeclaration& style);
-	virtual void InitChildren(wxSVGTextPositioningElement& element, const wxCSSStyleDeclaration& style);
-	virtual void AddChunk(const wxString& text, const wxCSSStyleDeclaration& style);
-	virtual void BeginChar();
+	virtual void Init(wxSVGTSpanElement& element, const wxCSSStyleDeclaration& style, wxSVGMatrix* matrix);
+	virtual void InitChildren(wxSVGTextPositioningElement& element, const wxCSSStyleDeclaration& style,
+			wxSVGMatrix* matrix);
+	virtual void AddChunk(const wxString& text, const wxCSSStyleDeclaration& style, wxSVGMatrix* matrix);
+	virtual void BeginChar(wxSVGMatrix* matrix);
 	virtual void EndChar();
 	virtual void EndTextAnchor();
 	wxSVGCanvasTextChunk* GetChunk(unsigned long& charnum);
     /** Converts text in path and saves in current chunk (m_chunk->path) */
-    virtual void InitText(const wxString& text, const wxCSSStyleDeclaration& style) = 0;
+    virtual void InitText(const wxString& text, const wxCSSStyleDeclaration& style, wxSVGMatrix* matrix) = 0;
 };
 
 /** Canvas item, that saves image (SVGImageElement) */
 class wxSVGCanvasImage: public wxSVGCanvasItem {
 public:
-	wxSVGCanvasImage(): wxSVGCanvasItem(wxSVG_CANVAS_ITEM_IMAGE), m_defHeightScale(1), m_svgImage(NULL) {}
-	wxSVGCanvasImage(wxSVGCanvasItemType type): wxSVGCanvasItem(type), m_defHeightScale(1), m_svgImage(NULL) {}
+	wxSVGCanvasImage(): wxSVGCanvasItem(wxSVG_CANVAS_ITEM_IMAGE), m_x(0), m_y(0), m_width(0), m_height(0),
+		m_defHeightScale(1), m_svgImage(NULL) {}
+	wxSVGCanvasImage(wxSVGCanvasItemType type): wxSVGCanvasItem(type), m_x(0), m_y(0), m_width(0), m_height(0),
+		m_defHeightScale(1), m_svgImage(NULL) {}
 	virtual ~wxSVGCanvasImage();
-	virtual void Init(wxSVGImageElement& element, const wxCSSStyleDeclaration& style);
+	virtual void Init(wxSVGImageElement& element, const wxCSSStyleDeclaration& style, wxProgressDialog* progressDlg);
 	virtual int GetDefaultWidth();
 	virtual int GetDefaultHeight();
 	const wxSVGPreserveAspectRatio& GetPreserveAspectRatio() { return m_preserveAspectRatio; }
@@ -188,7 +190,7 @@ class wxSVGCanvasVideo: public wxSVGCanvasImage {
 public:
 	wxSVGCanvasVideo();
 	virtual ~wxSVGCanvasVideo();
-	virtual void Init(wxSVGVideoElement& element, const wxCSSStyleDeclaration& style);
+	virtual void Init(wxSVGVideoElement& element, const wxCSSStyleDeclaration& style, wxProgressDialog* progressDlg);
 	double GetDuration() { return m_duration; }
 	
 public:
