@@ -3,7 +3,7 @@
 // Purpose:     wxSVGDocument - SVG render & data holder class
 // Author:      Alex Thuering
 // Created:     2005/01/17
-// RCS-ID:      $Id: SVGDocument.cpp,v 1.41 2011/11/24 00:02:55 ntalex Exp $
+// RCS-ID:      $Id: SVGDocument.cpp,v 1.46 2013/09/21 08:08:37 ntalex Exp $
 // Copyright:   (c) 2005 Alex Thuering
 // Licence:     wxWindows licence
 //////////////////////////////////////////////////////////////////////////////
@@ -40,27 +40,71 @@ void wxSVGDocument::Init() {
 	m_time = 0;
 }
 
+wxString wxSVGDocument::GetTitle() {
+	wxSVGElement* elem = (wxSVGElement*) GetRootElement()->GetChildren();
+	while (elem) {
+		if (elem->GetType() == wxSVGXML_ELEMENT_NODE && elem->GetDtd() == wxSVG_TITLE_ELEMENT) {
+			if (elem->GetChildren() && elem->GetFirstChild()->GetType() == wxSVGXML_TEXT_NODE) {
+				return elem->GetFirstChild()->GetContent();
+			}
+		}
+		elem = (wxSVGElement*) elem->GetNext();
+	}
+	return wxT("");
+}
+
+void wxSVGDocument::SetTitle(const wxString& title) {
+	wxSVGTitleElement* titleElem = NULL;
+	wxSVGElement* elem = (wxSVGElement*) GetRootElement()->GetChildren();
+	while (elem) {
+		if (elem->GetType() == wxSVGXML_ELEMENT_NODE && elem->GetDtd() == wxSVG_TITLE_ELEMENT) {
+			titleElem = (wxSVGTitleElement*) elem;
+		}
+		elem = (wxSVGElement*) elem->GetNext();
+	}
+	if (titleElem == NULL) {
+		titleElem = new wxSVGTitleElement;
+		GetRootElement()->AppendChild(titleElem);
+	}
+	if (titleElem->GetChildren() && elem->GetFirstChild()->GetType() == wxSVGXML_TEXT_NODE)
+		elem->GetFirstChild()->SetContent(title);
+	else
+		elem->AddChild(new wxSvgXmlNode(wxSVGXML_TEXT_NODE, wxEmptyString, title));
+}
+
+wxSVGElement* wxSVGDocument::GetElementById(const wxString& id) {
+	return GetRootElement() ? (wxSVGElement*) GetRootElement()->GetElementById(id) : NULL;
+}
+
 wxSvgXmlElement* wxSVGDocument::CreateElement(const wxString& tagName) {
 	return CreateElementNS(wxT(""), tagName);
 }
 
 #include "SVGDocument_CreateElement.cpp"
 
-wxSVGElement* wxSVGDocument::GetElementById(const wxString& id) {
-	return GetRootElement() ? (wxSVGElement*) GetRootElement()->GetElementById(id) : NULL;
-}
-
 double wxSVGDocument::GetDuration(wxSVGElement* parent) {
-	float result = 0;
+	double result = 0;
 	wxSVGElement* elem = (wxSVGElement*) parent->GetChildren();
 	while (elem) {
-		float duration = 0;
-		if (elem->GetType() == wxSVGXML_ELEMENT_NODE && elem->GetDtd() == wxSVG_VIDEO_ELEMENT)
-			duration = ((wxSVGVideoElement*) elem)->GetBegin() + ((wxSVGVideoElement*) elem)->GetDuration();
-		else if (elem->GetChildren())
-			duration = GetDuration(elem);
-		if (result < duration)
-			result = duration;
+		if (elem->GetType() == wxSVGXML_ELEMENT_NODE) {
+			double duration = 0;
+			switch (elem->GetDtd()) {
+				case wxSVG_VIDEO_ELEMENT:
+					duration = ((wxSVGVideoElement*) elem)->GetBegin() + ((wxSVGVideoElement*) elem)->GetDuration();
+					break;
+				case wxSVG_ANIMATE_ELEMENT:
+					duration = ((wxSVGAnimateElement*) elem)->GetBegin() + ((wxSVGAnimateElement*) elem)->GetDur();
+					break;
+				default:
+					if (elem->GetChildren()) {
+						duration = GetDuration(elem);
+					}
+					break;
+			}
+			if (result < duration) {
+				result = duration;
+			}
+		}
 		elem = (wxSVGElement*) elem->GetNext();
 	}
 	return result;
@@ -70,11 +114,32 @@ double wxSVGDocument::GetDuration() {
 	return GetDuration(GetRootElement());
 }
 
-void wxSVGDocument::SetCurrentTime(double seconds) {
-	m_time = seconds;
+void ApplyAnimation(wxSVGElement* parent) {
+	wxSVGElement* elem = (wxSVGElement*) parent->GetChildren();
+	while (elem) {
+		if (elem->GetType() == wxSVGXML_ELEMENT_NODE) {
+			switch (elem->GetDtd()) {
+				case wxSVG_ANIMATE_ELEMENT:
+					((wxSVGAnimateElement*) elem)->ApplyAnimation();
+					break;
+				default:
+					ApplyAnimation(elem);
+					break;
+			}
+		}
+		elem = (wxSVGElement*) elem->GetNext();
+	}
 }
 
-wxImage wxSVGDocument::Render(int width, int height, const wxSVGRect* rect, bool preserveAspectRatio, bool alpha) {
+void wxSVGDocument::SetCurrentTime(double seconds) {
+	m_time = seconds;
+	// animation
+	if (GetRootElement())
+		ApplyAnimation(GetRootElement());
+}
+
+wxImage wxSVGDocument::Render(int width, int height, const wxSVGRect* rect, bool preserveAspectRatio, bool alpha,
+		wxProgressDialog* progressDlg) {
 	if (!GetRootElement())
 		return wxImage();
 	
@@ -141,7 +206,8 @@ wxImage wxSVGDocument::Render(int width, int height, const wxSVGRect* rect, bool
 	m_canvas->Init(width, height, alpha);
 	if (!alpha)
 		m_canvas->Clear(*wxWHITE);
-	GetCanvas()->RenderElement(GetRootElement(), rect, &m_screenCTM, &GetRootElement()->GetStyle(), NULL, NULL);
+	GetCanvas()->RenderElement(GetRootElement(), rect, &m_screenCTM, &GetRootElement()->GetStyle(), NULL, NULL,
+			progressDlg);
 
 	return m_canvas->GetImage();
 }
@@ -153,6 +219,6 @@ wxImage wxSVGDocument::RenderElementById(const wxString& id) {
 	m_screenCTM = m_screenCTM.Translate(-10, -10);
 	
 	m_canvas->Clear();
-	GetCanvas()->RenderElement(element, rect, &m_screenCTM, &GetRootElement()->GetStyle(), NULL, NULL);
+	GetCanvas()->RenderElement(element, rect, &m_screenCTM, &GetRootElement()->GetStyle(), NULL, NULL, NULL);
 	return m_canvas->GetImage();
 }
