@@ -3,7 +3,7 @@
 // Purpose:     
 // Author:      Alex Thuering
 // Created:     2005/05/10
-// RCS-ID:      $Id: SVGFEGaussianBlurElement.cpp,v 1.4 2011/06/27 21:14:14 ntalex Exp $
+// RCS-ID:      $Id: SVGFEGaussianBlurElement.cpp,v 1.5 2012/01/08 02:42:15 ntalex Exp $
 // Copyright:   (c) 2005 Alex Thuering
 // Licence:     wxWindows licence
 //////////////////////////////////////////////////////////////////////////////
@@ -33,3 +33,10 @@ bool wxSVGFEGaussianBlurElement::SetCustomAttribute(const wxString& name, const
 	}
 	return false;
 }
+
+wxSvgXmlAttrHash wxSVGFEGaussianBlurElement::GetCustomAttributes() const {
+	wxSvgXmlAttrHash attrs;
+	if (m_stdDeviationX.GetBaseVal() > 0)
+		attrs.Add(wxT("stdDeviation"), wxString::Format(wxT("%g"), m_stdDeviationX.GetBaseVal()));
+	return attrs;
+}
