@@ -3,7 +3,7 @@
 // Purpose:     Cairo canvas path
 // Author:      Alex Thuering
 // Created:     2005/05/12
-// RCS-ID:      $Id: SVGCanvasPathCairo.cpp,v 1.10 2013/02/11 07:29:30 ntalex Exp $
+// RCS-ID:      $Id: SVGCanvasPathCairo.cpp,v 1.11 2013/05/01 07:15:41 ntalex Exp $
 // Copyright:   (c) 2005 Alex Thuering
 // Licence:     wxWindows licence
 //////////////////////////////////////////////////////////////////////////////
@@ -13,7 +13,7 @@
 
 wxSVGCanvasPathCairo::wxSVGCanvasPathCairo(cairo_surface_t* surface, wxSVGMatrix* matrix) {
 	m_cr = cairo_create(surface);
-#if !defined(__WXMAC__) && !defined(__WXMSW__)
+#if 0 //!defined(__WXMAC__) && !defined(__WXMSW__)
 	if (matrix) {
 		 // for correct checking of surface size when text is rendered using PangaCairo
 		cairo_matrix_t m;
